@@ -6,13 +6,13 @@ use warnings::register;
 use 5.006;
 
 # ABSTRACT: An extension of the File::stat module, provides additional methods.
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
+#pod =head1 SYNOPSIS
+#pod
 #pod =for test_synopsis
 #pod my ($st, $file);
 #pod
-#pod =head1 SYNOPSIS
-#pod
 #pod   use File::stat::Extra;
 #pod
 #pod   $st = lstat($file) or die "No $file: $!";
@@ -219,7 +219,7 @@ sub lstat(*) { ## no critic (Subroutines::ProhibitSubroutinePrototypes)
 #pod or not the current process would be allowed the specified access.
 #pod
 #pod I<ACCESS> is one of C<S_IRUSR>, C<S_IWUSR> or C<S_IXUSR> from the
-#pod L<Fcntl|Fcntl> module, and I<EFFECTIVE> indicates whether to use
+#pod L<Fcntl> module, and I<EFFECTIVE> indicates whether to use
 #pod effective (true) or real (false) ids.
 #pod
 #pod =cut
@@ -389,9 +389,10 @@ sub isSocket {
 #pod
 #pod Note: in case of the special file tests C<-t>, C<-T>, and C<-B>, the
 #pod file (handle) I<is> tested the I<first> time the operator is
-#pod used. After the first time, the initial result is re-used.
+#pod used. After the first time, the initial result is re-used and no
+#pod further testing of the file (handle) is performed.
 #pod
-#pod =method Unary C<""> (stringification)
+#pod =method Unary C<""> (stringification) operator
 #pod
 #pod The unary C<""> (stringification) operator is overloaded to return the the device and inode
 #pod numbers separated by a C<.> (C<I<dev>.I<ino>>). This yields a uniqe file identifier (as string).
@@ -403,11 +404,11 @@ sub isSocket {
 #pod object point to the same (hardlinked) file, you can simply say
 #pod something like this:
 #pod
-#pod     print 'Same file' if $ob1 == $ob2;
+#pod     print 'Same file' if $obj1 == $obj2;
 #pod
 #pod For objects created from an C<stat> of a symbolic link, the actual
 #pod I<destination> of the link is used in the comparison! If you want to
-#pod compare the actual symnlink file, use C<lstat> instead.
+#pod compare the actual symlink file, use C<lstat> instead.
 #pod
 #pod Note: All comparisons (also the numeric versions) are performed on the
 #pod full stringified versions of the object. This to prevent files on the
@@ -415,7 +416,7 @@ sub isSocket {
 #pod equally while they aren't (e.g., 5.10 and 5.100 compare equal
 #pod numerically but denote a different file).
 #pod
-#pod Note: the smartmatch C<~~> operator is obly overloaded on Perl version
+#pod Note: the smartmatch C<~~> operator is only overloaded on Perl version
 #pod 5.10 and above.
 #pod
 #pod =method Other operators
@@ -518,31 +519,10 @@ File::stat::Extra - An extension of the File::stat module, provides additional m
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
-  use File::stat::Extra;
-
-  $st = lstat($file) or die "No $file: $!";
-
-  if ($st->isLink) {
-      print "$file is a symbolic link";
-  }
-
-  if (-x $st) {
-      print "$file is executable";
-  }
-
-  use Fcntl 'S_IRUSR';
-  if ( $st->cando(S_IRUSR, 1) ) {
-      print "My effective uid can read $file";
-  }
-
-  if ($st == stat($file)) {
-      printf "%s and $file are the same", $st->file;
-  }
-
 =head1 DESCRIPTION
 
 This module's default exports override the core stat() and lstat()
@@ -638,7 +618,7 @@ Interprets the C<mode>, C<uid> and C<gid> fields, and returns whether
 or not the current process would be allowed the specified access.
 
 I<ACCESS> is one of C<S_IRUSR>, C<S_IWUSR> or C<S_IXUSR> from the
-L<Fcntl|Fcntl> module, and I<EFFECTIVE> indicates whether to use
+L<Fcntl> module, and I<EFFECTIVE> indicates whether to use
 effective (true) or real (false) ids.
 
 =head2 file
@@ -710,9 +690,10 @@ higer. The named access to these tests can still be used though.
 
 Note: in case of the special file tests C<-t>, C<-T>, and C<-B>, the
 file (handle) I<is> tested the I<first> time the operator is
-used. After the first time, the initial result is re-used.
+used. After the first time, the initial result is re-used and no
+further testing of the file (handle) is performed.
 
-=head2 Unary C<""> (stringification)
+=head2 Unary C<""> (stringification) operator
 
 The unary C<""> (stringification) operator is overloaded to return the the device and inode
 numbers separated by a C<.> (C<I<dev>.I<ino>>). This yields a uniqe file identifier (as string).
@@ -724,11 +705,11 @@ C<File::stat::Extra> object. So, to see if two C<File::stat::Extra>
 object point to the same (hardlinked) file, you can simply say
 something like this:
 
-    print 'Same file' if $ob1 == $ob2;
+    print 'Same file' if $obj1 == $obj2;
 
 For objects created from an C<stat> of a symbolic link, the actual
 I<destination> of the link is used in the comparison! If you want to
-compare the actual symnlink file, use C<lstat> instead.
+compare the actual symlink file, use C<lstat> instead.
 
 Note: All comparisons (also the numeric versions) are performed on the
 full stringified versions of the object. This to prevent files on the
@@ -736,7 +717,7 @@ same device, but with an inode number ending in a zero to compare
 equally while they aren't (e.g., 5.10 and 5.100 compare equal
 numerically but denote a different file).
 
-Note: the smartmatch C<~~> operator is obly overloaded on Perl version
+Note: the smartmatch C<~~> operator is only overloaded on Perl version
 5.10 and above.
 
 =head2 Other operators
@@ -746,6 +727,27 @@ have not been overloaded and will cause a run-time error.
 
 =for test_synopsis my ($st, $file);
 
+  use File::stat::Extra;
+
+  $st = lstat($file) or die "No $file: $!";
+
+  if ($st->isLink) {
+      print "$file is a symbolic link";
+  }
+
+  if (-x $st) {
+      print "$file is executable";
+  }
+
+  use Fcntl 'S_IRUSR';
+  if ( $st->cando(S_IRUSR, 1) ) {
+      print "My effective uid can read $file";
+  }
+
+  if ($st == stat($file)) {
+      printf "%s and $file are the same", $st->file;
+  }
+
 =head1 WARNINGS
 
 When a file (handle) can not be (l)stat-ed, a warning C<Unable to
@@ -779,8 +781,8 @@ do not, since the information required is not available.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website
-https://github.com/HayoBaan/File-stat-Extra/issues
+Please report any bugs or feature requests on the bugtracker
+L<website|https://github.com/HayoBaan/File-stat-Extra/issues>.
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -812,7 +814,7 @@ L<stat> and L<lstat> for the original C<stat> and C<lstat> functions.
 
 =head1 AUTHOR
 
-Hayo Baan <info@hayobaan.nl>
+Hayo Baan <hayobaan@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
